==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S502c2d5425ba2c329e58f02e0bf84d5e.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#ifndef S88bb36ec6c07b092c4f765e2ede10d4b
 
#define S88bb36ec6c07b092c4f765e2ede10d4b
 
#include "sconfig.h"
class Sa374ae40bab87d51f64df15ce1e0bd84; 
#include "Sdbb928b8a5a578da056c2bc5916736c2.h"

#include "S38a4a9a189a8b99a2ea436bf03c12109.h"

#include "S749d2b576e15d77f0d14f186077e9ace.h"

#if HAVE_TIME_H
 
#include <time.h>

#endif
 class Se307db07b3975fef922a80d07455ee5e; class S4951c7673332d59b70c5132a5ba33a77; class S7a8c30ba69067011071ba14cc1b4a63d; 
class S1f5c18fdf8eb15d7f37b2a00a8f27a4d; class S7824a773c722026c149f24519969579a; class Sc824eb6c6ab575c0af9d67fb1d9671fe; 
class Se874683a63cf56826e56cc704581d409; class S43a19b9d46c132a076a104b300237b4a { public: Sa374ae40bab87d51f64df15ce1e0bd84 
*S72122ce96bfec66e2396d2e25225d70a; long S6f5779dde267bb295283b1d8391c960f; time_t Sf2f978763db6d912bf7884dcff83036b; 
S419a71da9fe8b357adca33f8e84781c6 Sdce7c4174ce9323904a934a486c41288; S419a71da9fe8b357adca33f8e84781c6 
S2f5f2fc92fdea2a8a94170203b50239e; S419a71da9fe8b357adca33f8e84781c6 Sf72b4ca21027de6c8d403be4758b75f3; 
time_t Sdeba46f4e7679f19ef04109c4f2f3260; time_t S7fed13354c99c5cc6ff0f05eeea9f267; bool S3409b2b85563703f31f71296f63d80f6; 
unsigned long S2813dab64edada457779d7682be618e2; S1f5c18fdf8eb15d7f37b2a00a8f27a4d **Sc4ec0ab3a5700e1f241213e48cfadce6; 
unsigned long Se3e30e4e38ef167b1847ee727bd95238; long Sdc747497463cabf804f43af3a4981d5f; Se307db07b3975fef922a80d07455ee5e 
***S218f63acf35afe5021b4706caf888194; unsigned long Sb36720bf363576bd427135b213c20e96; unsigned long 
S303f640b4a964b1e88b85d32dc2abc1a; long S9aff2578b111729bc317b42addfe10da; unsigned long **S69b6acf9554895e850f83225c46b14b1; 
unsigned long *S10404c2dadce0f0e0b34d65daf9ec434; unsigned long *S29283e068da07ff94252a61cc9a56d34; 
unsigned long **S42b97aa34107abfc3c7bf7caf01b84d4; unsigned long *Sf696148eec87a3823121c8f055c79a7a; 
long **Sda690b4f1f86a80d09e2b79331302d1f; char **Scdf21c5a60656a4a1e5c2b2917def28f; unsigned long *S73542f6a359652d545afc9e2fc8695ac; 
unsigned long *S6f4c59c26fc3632bcf914f68417bee0e; bool *S356f87438f75795b8d113cb1ac29458f; bool *Sb3a0d433146c211a7bc4f1f5618004f0; 
 unsigned long Sfb86e37a94ace61461fadc957ad34f4e; unsigned long *S63a9f0ea7bb98050796b649e85481845; 
unsigned long Sa5f5c44399ef6a4d2b41bc2297e7ede8; time_t Se32a2c6a48a220f5e4cd34d6570d8bf4; time_t Sff312f306af23b2f95cdeb95ba943655; 
S9c023f942cf5210c8f3affabe7ed7196 *S8fdc434248ca256f38ed1fe4320fc363; S749d2b576e15d77f0d14f186077e9ace 
S3eda10e7145b43b9fa553598b815e3a6; unsigned long S1ab244d34d25603f7a6a42af69ed2a62;   Se307db07b3975fef922a80d07455ee5e 
**S962face850b835b3456a7c62a004bd99; Se307db07b3975fef922a80d07455ee5e **S517d4fda45392239190bb13fc83f99d7; 
unsigned long S9d4b5b5c96a0179dbaade7befe0a45a3; S7824a773c722026c149f24519969579a *S83ed8c2e9ec662b925b0254457a37c6d; 
 long Scef47ae68d74514de762faac48d89932; S749d2b576e15d77f0d14f186077e9ace S07237afd1cc1ef7a4aca35574950a783; 
unsigned long Sc7f6b7e255637da6bbdccafcea10695b; double S11b63f67789c3a74571a34f777a493bc; double S112960f4ccb6419647f6e1c97c6aad2b; 
double S0311a376b05b3782a05a6b4248e4d5c6; unsigned long S6a029b986877466c40652943f408bdf2;  void *S2af0f074d36952de5a358045e688c223; 
S749d2b576e15d77f0d14f186077e9ace Sae0d1cf12ef48e22c2c42a675edfbfd9; bool S68bad9cc8e145ef616a5f3d37629c67e; 
bool S9ed9b51749f4214f886e2d9381ea609b; long Sb12cd93d8191467da09dde94c72f587b; long S766240e7e817a59c061499e9a6a6631c; 
Se874683a63cf56826e56cc704581d409 **Sefd24906d9b22928405e9a6960211d55;        S749d2b576e15d77f0d14f186077e9ace 
Sbb1ed869af424bed9f8105a1fb8fab9c; bool S00afb71b11630ef405521aa42d466ded; bool Sad8ca90d83db49dda6664ced2340b38d; 
bool S55c9863c7eadd6d1b0ae84dafafe70e1;      S419a71da9fe8b357adca33f8e84781c6 Seb750e7d784238712382cd0c682217f1; 
S419a71da9fe8b357adca33f8e84781c6 Sd5d84848f5a7ba21943c0d82ab5ece76; S419a71da9fe8b357adca33f8e84781c6 
Saa7f878d4258cfffa942ee89609343cd; S419a71da9fe8b357adca33f8e84781c6 S086f38b9b70e9624e5cfc8695f7bc16c; 
S419a71da9fe8b357adca33f8e84781c6 S566086ceea5baba3be78a806ce5482d9; unsigned long S18ffedd362597a082b04a5ef6196d509; 
S419a71da9fe8b357adca33f8e84781c6 S97fed0279d17ec529ad262c17c8a6bec; unsigned long S19b1c671d76faaef639df24a4ca22712; 
time_t Sc226feb16cb476f87408f5a13b5778b8; unsigned long S3bf2df4f6220ca79d18fe044352a3f90;   bool Se856ba9c66234e6affae397a04773561; 
bool S69b9ca96f93df5f637c716ebf478d6e1; bool S435ea9cf9dd4fd3dd661296dcab6e671; bool Sa6c4fc255cae6fa8fa477d0734904e9a; 
Se307db07b3975fef922a80d07455ee5e *Sffa5c896aa75d796eaccb14a3a07e205; S43a19b9d46c132a076a104b300237b4a(Sa374ae40bab87d51f64df15ce1e0bd84 
*S908ea47162d020873e19f62a8278d2d0); ~S43a19b9d46c132a076a104b300237b4a(void); S749d2b576e15d77f0d14f186077e9ace 
S9d09efc2ea50441af211f24ec14347bd(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S703cd63ae864cb7f50dfd0019a3e6d8c(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &Sb068931cc450442b63f5b3d276ea4297, const S749d2b576e15d77f0d14f186077e9ace 
&S2063c1608d6e0baf80249c42e2be5804); }; 
#endif

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S502c2d5425ba2c329e58f02e0bf84d5e.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#ifndef S88bb36ec6c07b092c4f765e2ede10d4b
 
#define S88bb36ec6c07b092c4f765e2ede10d4b
 
#include "sconfig.h"
class Sa374ae40bab87d51f64df15ce1e0bd84; 
#include "Sdbb928b8a5a578da056c2bc5916736c2.h"

#include "S38a4a9a189a8b99a2ea436bf03c12109.h"

#include "S749d2b576e15d77f0d14f186077e9ace.h"

#if HAVE_TIME_H
 
#include <time.h>

#endif
 class Se307db07b3975fef922a80d07455ee5e; class S4951c7673332d59b70c5132a5ba33a77; class S7a8c30ba69067011071ba14cc1b4a63d; 
class S1f5c18fdf8eb15d7f37b2a00a8f27a4d; class S7824a773c722026c149f24519969579a; class Sc824eb6c6ab575c0af9d67fb1d9671fe; 
class Se874683a63cf56826e56cc704581d409; class S43a19b9d46c132a076a104b300237b4a { private: S749d2b576e15d77f0d14f186077e9ace 
Sae0d1cf12ef48e22c2c42a675edfbfd9; S749d2b576e15d77f0d14f186077e9ace Sfb9c6c2a78a083ba4ac6e6f11fea125f; 
S749d2b576e15d77f0d14f186077e9ace S3d54abafb7030eed4e15f46bdc1581a8; public: Sa374ae40bab87d51f64df15ce1e0bd84 
*S72122ce96bfec66e2396d2e25225d70a; long S6f5779dde267bb295283b1d8391c960f; time_t Sf2f978763db6d912bf7884dcff83036b; 
S419a71da9fe8b357adca33f8e84781c6 Sdce7c4174ce9323904a934a486c41288; S419a71da9fe8b357adca33f8e84781c6 
S2f5f2fc92fdea2a8a94170203b50239e; S419a71da9fe8b357adca33f8e84781c6 Sf72b4ca21027de6c8d403be4758b75f3; 
time_t Sdeba46f4e7679f19ef04109c4f2f3260; time_t S7fed13354c99c5cc6ff0f05eeea9f267; bool S3409b2b85563703f31f71296f63d80f6; 
unsigned long S2813dab64edada457779d7682be618e2; S1f5c18fdf8eb15d7f37b2a00a8f27a4d **Sc4ec0ab3a5700e1f241213e48cfadce6; 
unsigned long Se3e30e4e38ef167b1847ee727bd95238; long Sdc747497463cabf804f43af3a4981d5f; Se307db07b3975fef922a80d07455ee5e 
***S218f63acf35afe5021b4706caf888194; unsigned long Sb36720bf363576bd427135b213c20e96; unsigned long 
S303f640b4a964b1e88b85d32dc2abc1a; long S9aff2578b111729bc317b42addfe10da; unsigned long **S69b6acf9554895e850f83225c46b14b1; 
unsigned long *S10404c2dadce0f0e0b34d65daf9ec434; unsigned long *S29283e068da07ff94252a61cc9a56d34; 
unsigned long **S42b97aa34107abfc3c7bf7caf01b84d4; unsigned long *Sf696148eec87a3823121c8f055c79a7a; 
long **Sda690b4f1f86a80d09e2b79331302d1f; char **Scdf21c5a60656a4a1e5c2b2917def28f; unsigned long *S73542f6a359652d545afc9e2fc8695ac; 
unsigned long *S6f4c59c26fc3632bcf914f68417bee0e; bool *S356f87438f75795b8d113cb1ac29458f; bool *Sb3a0d433146c211a7bc4f1f5618004f0; 
 unsigned long Sfb86e37a94ace61461fadc957ad34f4e; unsigned long *S63a9f0ea7bb98050796b649e85481845; 
unsigned long Sa5f5c44399ef6a4d2b41bc2297e7ede8; time_t Se32a2c6a48a220f5e4cd34d6570d8bf4; time_t Sff312f306af23b2f95cdeb95ba943655; 
S9c023f942cf5210c8f3affabe7ed7196 *S8fdc434248ca256f38ed1fe4320fc363; S749d2b576e15d77f0d14f186077e9ace 
S3eda10e7145b43b9fa553598b815e3a6; unsigned long S1ab244d34d25603f7a6a42af69ed2a62;   Se307db07b3975fef922a80d07455ee5e 
**S962face850b835b3456a7c62a004bd99; Se307db07b3975fef922a80d07455ee5e **S517d4fda45392239190bb13fc83f99d7; 
unsigned long S9d4b5b5c96a0179dbaade7befe0a45a3; S7824a773c722026c149f24519969579a *S83ed8c2e9ec662b925b0254457a37c6d; 
 long Scef47ae68d74514de762faac48d89932; S749d2b576e15d77f0d14f186077e9ace S07237afd1cc1ef7a4aca35574950a783; 
unsigned long Sc7f6b7e255637da6bbdccafcea10695b; double S11b63f67789c3a74571a34f777a493bc; double S112960f4ccb6419647f6e1c97c6aad2b; 
double S0311a376b05b3782a05a6b4248e4d5c6; unsigned long S6a029b986877466c40652943f408bdf2;  void *S2af0f074d36952de5a358045e688c223; 
bool S68bad9cc8e145ef616a5f3d37629c67e; bool S9ed9b51749f4214f886e2d9381ea609b; long Sb12cd93d8191467da09dde94c72f587b; 
long S766240e7e817a59c061499e9a6a6631c; Se874683a63cf56826e56cc704581d409 **Sefd24906d9b22928405e9a6960211d55; 
       S749d2b576e15d77f0d14f186077e9ace Sbb1ed869af424bed9f8105a1fb8fab9c; bool S00afb71b11630ef405521aa42d466ded; 
bool Sad8ca90d83db49dda6664ced2340b38d; bool S55c9863c7eadd6d1b0ae84dafafe70e1;      S419a71da9fe8b357adca33f8e84781c6 
Seb750e7d784238712382cd0c682217f1; S419a71da9fe8b357adca33f8e84781c6 Sd5d84848f5a7ba21943c0d82ab5ece76; 
S419a71da9fe8b357adca33f8e84781c6 Saa7f878d4258cfffa942ee89609343cd; S419a71da9fe8b357adca33f8e84781c6 
S086f38b9b70e9624e5cfc8695f7bc16c; S419a71da9fe8b357adca33f8e84781c6 S566086ceea5baba3be78a806ce5482d9; 
unsigned long S18ffedd362597a082b04a5ef6196d509; S419a71da9fe8b357adca33f8e84781c6 S97fed0279d17ec529ad262c17c8a6bec; 
unsigned long S19b1c671d76faaef639df24a4ca22712; time_t Sc226feb16cb476f87408f5a13b5778b8; unsigned 
long S3bf2df4f6220ca79d18fe044352a3f90;   bool Se856ba9c66234e6affae397a04773561; bool S69b9ca96f93df5f637c716ebf478d6e1; 
bool S435ea9cf9dd4fd3dd661296dcab6e671; bool Sa6c4fc255cae6fa8fa477d0734904e9a; Se307db07b3975fef922a80d07455ee5e 
*Sffa5c896aa75d796eaccb14a3a07e205; const char *S842239e8e12a75994a53d666002de3b1(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, bool Sbee0ed37d91ca4e2cb76ed8b0b7c47e3 = true); void S5f32c1e52a05117a71c3bb734b7dd93a(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179, const char *S4ec1b477cd0232b832c1899905ec51a4); void Sa2a014f645005027d7718ace372c87ca(const 
char *S4ec1b477cd0232b832c1899905ec51a4); S43a19b9d46c132a076a104b300237b4a(Sa374ae40bab87d51f64df15ce1e0bd84 
*S908ea47162d020873e19f62a8278d2d0); ~S43a19b9d46c132a076a104b300237b4a(void); S749d2b576e15d77f0d14f186077e9ace 
S9d09efc2ea50441af211f24ec14347bd(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
void S703cd63ae864cb7f50dfd0019a3e6d8c(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179, 
const S749d2b576e15d77f0d14f186077e9ace &Sb068931cc450442b63f5b3d276ea4297, const S749d2b576e15d77f0d14f186077e9ace 
&S2063c1608d6e0baf80249c42e2be5804); }; 
#endif
